==> org.eclipse.scout.rt.client.source_3.8.2.201302111336.jar: org/eclipse/scout/rt/client/ui/form/fields/composer/DataModelOperatorLookupCall.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.rt.client.ui.form.fields.composer;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.scout.commons.exception.ProcessingException;
import org.eclipse.scout.rt.shared.data.model.IDataModelAttribute;
import org.eclipse.scout.rt.shared.data.model.IDataModelAttributeOp;
import org.eclipse.scout.rt.shared.services.lookup.LocalLookupCall;
import org.eclipse.scout.rt.shared.services.lookup.LookupRow;

/**
 * Convenience lookup call to present {@link IDataModelAttribute#getOperators()}
 * <p>
 * This lookup call expects the property {@link #setAttribute(IDataModelAttribute)} to be set.
 */
public class DataModelOperatorLookupCall extends LocalLookupCall {
  private static final long serialVersionUID = 1L;

  private IDataModelAttribute m_attribute;

  public void setAttribute(IDataModelAttribute attribute) {
    m_attribute = attribute;
  }

  public IDataModelAttribute getAttribute() {
    return m_attribute;
  }

  @Override
  protected List<LookupRow> execCreateLookupRows() throws ProcessingException {
    List<LookupRow> result = new ArrayList<LookupRow>();
    IDataModelAttributeOp[] ops = null;
    if (m_attribute != null) {
      ops = m_attribute.getOperators();
    }
    if (ops != null) {
      for (IDataModelAttributeOp op : ops) {
        String text = op.getShortText();
        if (text != null && text.indexOf("{0}") >= 0) {
          text = text.replace("{0}", "n");
        }
        if (text != null && text.indexOf("{1}") >= 0) {
          text = text.replace("{1}", "m");
        }
        result.add(new LookupRow(op, text));
      }
    }

    return result;
  }
}

==> org.eclipse.scout.rt.client.source_4.0.200.20150820-1339.jar: org/eclipse/scout/rt/client/ui/form/fields/composer/DataModelOperatorLookupCall.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.rt.client.ui.form.fields.composer;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.scout.commons.exception.ProcessingException;
import org.eclipse.scout.rt.shared.data.model.IDataModelAttribute;
import org.eclipse.scout.rt.shared.data.model.IDataModelAttributeOp;
import org.eclipse.scout.rt.shared.services.lookup.ILookupRow;
import org.eclipse.scout.rt.shared.services.lookup.LocalLookupCall;
import org.eclipse.scout.rt.shared.services.lookup.LookupRow;

/**
 * Convenience lookup call to present {@link IDataModelAttribute#getOperators()}
 * <p>
 * This lookup call expects the property {@link #setAttribute(IDataModelAttribute)} to be set.
 */
public class DataModelOperatorLookupCall extends LocalLookupCall<IDataModelAttributeOp> {
  private static final long serialVersionUID = 1L;

  private IDataModelAttribute m_attribute;

  public void setAttribute(IDataModelAttribute attribute) {
    m_attribute = attribute;
  }

  public IDataModelAttribute getAttribute() {
    return m_attribute;
  }

  @Override
  protected List<ILookupRow<IDataModelAttributeOp>> execCreateLookupRows() throws ProcessingException {
    List<ILookupRow<IDataModelAttributeOp>> result = new ArrayList<ILookupRow<IDataModelAttributeOp>>();
    List<IDataModelAttributeOp> ops = null;
    if (m_attribute != null) {
      ops = m_attribute.getOperators();
    }
    if (ops != null) {
      for (IDataModelAttributeOp op : ops) {
        String text = op.getShortText();
        if (text != null && text.indexOf("{0}") >= 0) {
          text = text.replace("{0}", "n");
        }
        if (text != null && text.indexOf("{1}") >= 0) {
          text = text.replace("{1}", "m");
        }
        result.add(new LookupRow<IDataModelAttributeOp>(op, text));
      }
    }

    return result;
  }
}
